@@ -9,7 +9,7 @@
 #include "pimcommon_export.h"
 
 #include <PimCommon/SpellCheckLineEdit>
-namespace TextAutoCorrection
+namespace TextAutoCorrectionCore
 {
 class AutoCorrection;
 }
@@ -28,9 +28,8 @@ public:
     explicit LineEditWithAutoCorrection(QWidget *parent, const QString &configFile);
     ~LineEditWithAutoCorrection() override;
 
-    Q_REQUIRED_RESULT TextAutoCorrection::AutoCorrection *autocorrection() const;
-    void setAutocorrection(TextAutoCorrection::AutoCorrection *autocorrect);
-
+    [[nodiscard]] TextAutoCorrectionCore::AutoCorrection *autocorrection() const;
+    void setAutocorrection(TextAutoCorrectionCore::AutoCorrection *autocorrect);
     void setAutocorrectionLanguage(const QString &language);
 
 protected:
