@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2016-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -33,14 +33,14 @@ protected:
 
     virtual void help();
 
-    Q_REQUIRED_RESULT QDialogButtonBox *buttonBox() const;
+    [[nodiscard]] QDialogButtonBox *buttonBox() const;
 
 private:
-    void slotHelpClicked();
-    void slotAccepted();
-    void slotRestoreDefaultClicked();
-    void saveConfig();
-    void readConfig();
+    PIMCOMMON_NO_EXPORT void slotHelpClicked();
+    PIMCOMMON_NO_EXPORT void slotAccepted();
+    PIMCOMMON_NO_EXPORT void slotRestoreDefaultClicked();
+    PIMCOMMON_NO_EXPORT void saveConfig();
+    PIMCOMMON_NO_EXPORT void readConfig();
     QDialogButtonBox *mButtonBox = nullptr;
 };
 }
