@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2016-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -13,9 +13,7 @@ AbstractGenericPlugin::AbstractGenericPlugin(QObject *parent)
 {
 }
 
-AbstractGenericPlugin::~AbstractGenericPlugin()
-{
-}
+AbstractGenericPlugin::~AbstractGenericPlugin() = default;
 
 bool AbstractGenericPlugin::hasPopupMenuSupport() const
 {
@@ -39,8 +37,8 @@ bool AbstractGenericPlugin::hasStatusBarSupport() const
 
 void AbstractGenericPlugin::showConfigureDialog(QWidget *parent)
 {
-    Q_UNUSED(parent);
-    //Reimplement it.
+    Q_UNUSED(parent)
+    // Reimplement it.
 }
 
 void AbstractGenericPlugin::setIsEnabled(bool enabled)
@@ -52,3 +50,5 @@ bool AbstractGenericPlugin::isEnabled() const
 {
     return mIsEnabled;
 }
+
+#include "moc_abstractgenericplugin.cpp"
