@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2016-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -21,14 +21,23 @@ class GenericPlugin;
 class PIMCOMMON_EXPORT ActionType
 {
 public:
-    enum Type { Tools = 0, Edit = 1, File = 2, Action = 3, PopupMenu = 4, ToolBar = 5, Message = 6, Folder = 7 };
-    ActionType()
-    {
-    }
+    enum Type {
+        Tools = 0,
+        Edit = 1,
+        File = 2,
+        Action = 3,
+        PopupMenu = 4,
+        ToolBar = 5,
+        Message = 6,
+        Folder = 7,
+    };
+    ActionType() = default;
 
     ActionType(QAction *action, Type type);
-    Q_REQUIRED_RESULT QAction *action() const;
-    Q_REQUIRED_RESULT Type type() const;
+    [[nodiscard]] QAction *action() const;
+    [[nodiscard]] Type type() const;
+
+    [[nodiscard]] bool operator==(const ActionType &other) const;
 
 private:
     QAction *mAction = nullptr;
@@ -44,10 +53,10 @@ public:
     ~AbstractGenericPluginInterface() override;
 
     void setParentWidget(QWidget *parent);
-    Q_REQUIRED_RESULT QWidget *parentWidget() const;
+    [[nodiscard]] QWidget *parentWidget() const;
 
     void setPlugin(AbstractGenericPlugin *plugin);
-    Q_REQUIRED_RESULT AbstractGenericPlugin *plugin() const;
+    [[nodiscard]] AbstractGenericPlugin *plugin() const;
 
     virtual void createAction(KActionCollection *ac) = 0;
     virtual void exec() = 0;
