@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -23,8 +23,8 @@ public:
     {
     }
 
-    Q_REQUIRED_RESULT QIcon typeToIcon(ShareServiceUrlManager::ServiceType type) const;
-    Q_REQUIRED_RESULT QString typeToI18n(ShareServiceUrlManager::ServiceType type) const;
+    [[nodiscard]] QIcon typeToIcon(ShareServiceUrlManager::ServiceType type) const;
+    [[nodiscard]] QString typeToI18n(ShareServiceUrlManager::ServiceType type) const;
     void initializeMenu();
     KActionMenu *mMenu = nullptr;
     ShareServiceUrlManager *const q;
@@ -207,3 +207,5 @@ void ShareServiceUrlManager::openUrl(const QUrl &url)
         qCDebug(PIMCOMMON_LOG) << "url is invalid.";
     }
 }
+
+#include "moc_shareserviceurlmanager.cpp"
