@@ -1,29 +1,36 @@
 /*
-  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "templateeditdialog.h"
-#include <KPIMTextEdit/PlainTextEditor>
-#include <KPIMTextEdit/PlainTextEditorWidget>
-#include <Libkdepim/LineEditCatchReturnKey>
+#include <KLineEditEventHandler>
+#include <TextCustomEditor/PlainTextEditor>
+#include <TextCustomEditor/PlainTextEditorWidget>
 
 #include <KLocalizedString>
 #include <QLineEdit>
 
 #include <KConfigGroup>
 #include <KSharedConfig>
+#include <KWindowConfig>
 #include <QDialogButtonBox>
 #include <QHBoxLayout>
 #include <QLabel>
 #include <QPushButton>
 #include <QVBoxLayout>
+#include <QWindow>
 
 using namespace PimCommon;
-
+namespace
+{
+static const char myTemplateEditDialogConfigGroupName[] = "TemplateEditDialog";
+}
 TemplateEditDialog::TemplateEditDialog(QWidget *parent, bool defaultTemplate)
     : QDialog(parent)
+    , mTextEdit(new TextCustomEditor::PlainTextEditorWidget(this))
+    , mTemplateNameEdit(new QLineEdit(this))
 {
     setWindowTitle(defaultTemplate ? i18nc("@title:window", "Default template") : i18nc("@title:window", "Template"));
     auto mainLayout = new QVBoxLayout(this);
@@ -51,15 +58,13 @@ TemplateEditDialog::TemplateEditDialog(QWidget *parent, bool defaultTemplate)
     auto label = new QLabel(i18n("Name:"));
     hbox->addWidget(label);
 
-    mTemplateNameEdit = new QLineEdit;
-    new KPIM::LineEditCatchReturnKey(mTemplateNameEdit, this);
+    KLineEditEventHandler::catchReturnKey(mTemplateNameEdit);
     mTemplateNameEdit->setClearButtonEnabled(!defaultTemplate);
     mTemplateNameEdit->setReadOnly(defaultTemplate);
     hbox->addWidget(mTemplateNameEdit);
 
     vbox->addLayout(hbox);
 
-    mTextEdit = new KPIMTextEdit::PlainTextEditorWidget;
     mTextEdit->setReadOnly(defaultTemplate);
     vbox->addWidget(mTextEdit);
 
@@ -80,19 +85,19 @@ TemplateEditDialog::~TemplateEditDialog()
     writeConfig();
 }
 
-void TemplateEditDialog::writeConfig()
-{
-    KConfigGroup group(KSharedConfig::openStateConfig(), "TemplateEditDialog");
-    group.writeEntry("Size", size());
-}
-
 void TemplateEditDialog::readConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), "TemplateEditDialog");
-    const QSize sizeDialog = group.readEntry("Size", QSize(600, 400));
-    if (sizeDialog.isValid()) {
-        resize(sizeDialog);
-    }
+    create(); // ensure a window is created
+    windowHandle()->resize(QSize(300, 200));
+    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1String(myTemplateEditDialogConfigGroupName));
+    KWindowConfig::restoreWindowSize(windowHandle(), group);
+    resize(windowHandle()->size()); // workaround for QTBUG-40584
+}
+
+void TemplateEditDialog::writeConfig()
+{
+    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1String(myTemplateEditDialogConfigGroupName));
+    KWindowConfig::saveWindowSize(windowHandle(), group);
 }
 
 void TemplateEditDialog::slotTemplateChanged()
@@ -119,3 +124,5 @@ QString TemplateEditDialog::templateName() const
 {
     return mTemplateNameEdit->text();
 }
+
+#include "moc_templateeditdialog.cpp"
