@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -9,7 +9,7 @@
 #include <QDialog>
 
 class QLineEdit;
-namespace KPIMTextEdit
+namespace TextCustomEditor
 {
 class PlainTextEditorWidget;
 }
@@ -23,17 +23,17 @@ public:
     ~TemplateEditDialog() override;
 
     void setTemplateName(const QString &name);
-    Q_REQUIRED_RESULT QString templateName() const;
+    [[nodiscard]] QString templateName() const;
 
     void setScript(const QString &);
-    Q_REQUIRED_RESULT QString script() const;
+    [[nodiscard]] QString script() const;
 
 private:
     void slotTemplateChanged();
     void readConfig();
     void writeConfig();
-    KPIMTextEdit::PlainTextEditorWidget *mTextEdit = nullptr;
-    QLineEdit *mTemplateNameEdit = nullptr;
+    TextCustomEditor::PlainTextEditorWidget *const mTextEdit;
+    QLineEdit *const mTemplateNameEdit;
     QPushButton *mOkButton = nullptr;
 };
 }
