@@ -25,13 +25,14 @@ namespace PimCommon
  */
 namespace Util
 {
-Q_REQUIRED_RESULT PIMCOMMON_EXPORT OrgKdeAkonadiImapSettingsInterface *createImapSettingsInterface(const QString &ident);
+[[nodiscard]] PIMCOMMON_EXPORT OrgKdeAkonadiImapSettingsInterface *createImapSettingsInterface(const QString &ident);
 PIMCOMMON_EXPORT void saveTextAs(const QString &text, const QString &filter, QWidget *parent, const QUrl &url = QUrl(), const QString &caption = QString());
-Q_REQUIRED_RESULT PIMCOMMON_EXPORT bool saveToFile(const QString &filename, const QString &text);
-Q_REQUIRED_RESULT PIMCOMMON_EXPORT QString loadToFile(const QString &filter, QWidget *parent, const QUrl &url = QUrl(), const QString &caption = QString());
+[[nodiscard]] PIMCOMMON_EXPORT bool saveToFile(const QString &filename, const QString &text);
+[[nodiscard]] PIMCOMMON_EXPORT QString loadToFile(const QString &filter, QWidget *parent, const QUrl &url = QUrl(), const QString &caption = QString());
 PIMCOMMON_EXPORT void invokeHelp(const QString &docfile, const QString &anchor = QString());
-Q_REQUIRED_RESULT PIMCOMMON_EXPORT bool isImapResource(const QString &identifier);
-Q_REQUIRED_RESULT PIMCOMMON_EXPORT QStringList generateEmailList(const QStringList &list);
+[[nodiscard]] PIMCOMMON_EXPORT bool isImapResource(const QString &identifier);
+[[nodiscard]] PIMCOMMON_EXPORT QStringList generateEmailList(const QStringList &list);
+// Only for testing
+[[nodiscard]] PIMCOMMON_EXPORT QUrl generateHelpUrl(const QString &docfile, const QString &anchor = QString());
 }
 }
-
