@@ -30,7 +30,7 @@ public:
     {
     }
 
-    Q_REQUIRED_RESULT QString suggestName(const QUrl &baseURL, const QString &oldName);
+    [[nodiscard]] QString suggestName(const QUrl &baseURL, const QString &oldName);
 
     const QUrl url;
     QCheckBox *applyAll = nullptr;
@@ -86,10 +86,10 @@ QString PimCommon::RenameFileDialog::RenameFileDialogPrivate::suggestName(const
         exists = QFileInfo::exists(baseURL.toLocalFile() + QLatin1Char('/') + suggestedName);
     }
 
-    if (!exists) {
-        return suggestedName;
-    } else { // already exists -> recurse
+    if (exists) { // already exists -> recurse
         return suggestName(baseURL, suggestedName);
+    } else {
+        return suggestedName;
     }
 }
 
@@ -171,7 +171,7 @@ void RenameFileDialog::slotRenamePressed()
     if (newName().isLocalFile()) {
         fileExists = QFile::exists(newName().path());
     } else {
-        auto job = KIO::statDetails(newName(), KIO::StatJob::DestinationSide, KIO::StatBasic);
+        auto job = KIO::stat(newName(), KIO::StatJob::DestinationSide, KIO::StatBasic);
         KJobWidgets::setWindow(job, this);
         fileExists = job->exec();
     }
@@ -210,3 +210,5 @@ QUrl RenameFileDialog::newName() const
 
     return newDest;
 }
+
+#include "moc_renamefiledialog.cpp"
