@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2016-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -27,7 +27,7 @@
 #include <QDBusReply>
 
 using namespace PimCommon;
-//#define SEARCHCONTACT_AKONADI 1
+// #define SEARCHCONTACT_AKONADI 1
 
 AclModifyJob::AclModifyJob(QObject *parent)
     : QObject(parent)
@@ -240,7 +240,7 @@ void AclModifyJob::slotFetchCollectionFinished(const Akonadi::Collection::List &
     if (KMessageBox::warningContinueCancelList(nullptr,
                                                i18n("Do you really want to apply the folder's permissions to these subfolders?"),
                                                folderNames,
-                                               i18n("Apply Permissions"))
+                                               i18nc("@title:window", "Apply Permissions"))
         != KMessageBox::Continue) {
         deleteLater();
         qCDebug(PIMCOMMONAKONADI_LOG) << "AclModifyJob: User canceled .";
@@ -265,3 +265,5 @@ void AclModifyJob::setRecursive(bool recursive)
 {
     mRecursive = recursive;
 }
+
+#include "moc_aclmodifyjob.cpp"
