@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -15,17 +15,15 @@ CollectionAclWidgetTest::CollectionAclWidgetTest(QObject *parent)
 {
 }
 
-CollectionAclWidgetTest::~CollectionAclWidgetTest()
-{
-}
+CollectionAclWidgetTest::~CollectionAclWidgetTest() = default;
 
 void CollectionAclWidgetTest::shouldHaveDefaultValue()
 {
     PimCommon::CollectionAclWidget w;
     QVERIFY(w.aclManager());
-    auto *listView = w.findChild<QListView *>(QStringLiteral("list_view"));
+    auto listView = w.findChild<QListView *>(QStringLiteral("list_view"));
     QVERIFY(listView);
-    auto *button = w.findChild<QPushButton *>(QStringLiteral("add"));
+    auto button = w.findChild<QPushButton *>(QStringLiteral("add"));
     QVERIFY(button);
     button = w.findChild<QPushButton *>(QStringLiteral("edit"));
     QVERIFY(button);
@@ -34,3 +32,5 @@ void CollectionAclWidgetTest::shouldHaveDefaultValue()
 }
 
 QTEST_MAIN(CollectionAclWidgetTest)
+
+#include "moc_collectionaclwidgettest.cpp"
