@@ -119,7 +119,7 @@ void AddresseeLineEditPrivate::init()
             connect(box, &KCompletionBox::userCancelled, this, &AddresseeLineEditPrivate::slotUserCancelled);
             connect(AddresseeLineEditManager::self()->ldapTimer(), &QTimer::timeout, this, &AddresseeLineEditPrivate::slotStartLDAPLookup);
             connect(AddresseeLineEditManager::self()->ldapSearch(),
-                    qOverload<const KLDAP::LdapResult::List &>(&KLDAP::LdapClientSearch::searchData),
+                    qOverload<const KLDAPWidgets::LdapResult::List &>(&KLDAPWidgets::LdapClientSearch::searchData),
                     this,
                     &AddresseeLineEditPrivate::slotLDAPSearchData);
 
@@ -283,7 +283,7 @@ const QStringList PimCommon::AddresseeLineEditPrivate::adjustedCompletionItems(b
 
     if (AddresseeLineEditManager::self()->completion()->order() == KCompletion::Weighted) {
         // Sort the sections
-        QVector<SourceWithWeight> sourcesAndWeights;
+        QList<SourceWithWeight> sourcesAndWeights;
         const int numberOfCompletionSources(AddresseeLineEditManager::self()->completionSources.count());
         sourcesAndWeights.reserve(numberOfCompletionSources);
         for (int i = 0; i < numberOfCompletionSources; ++i) {
@@ -471,7 +471,7 @@ void AddresseeLineEditPrivate::doCompletion(bool ctrlT)
             break;
         }
         // else: fall-through to the CompletionPopup case
-        Q_FALLTHROUGH();
+        [[fallthrough]];
 
     case KCompletion::CompletionPopup: {
         const QStringList items = adjustedCompletionItems(false);
@@ -593,13 +593,13 @@ void AddresseeLineEditPrivate::slotStartLDAPLookup()
     }
 }
 
-void AddresseeLineEditPrivate::slotLDAPSearchData(const KLDAP::LdapResult::List &results)
+void AddresseeLineEditPrivate::slotLDAPSearchData(const KLDAPWidgets::LdapResult::List &results)
 {
     if (results.isEmpty() || AddresseeLineEditManager::self()->addressLineEdit() != q) {
         return;
     }
 
-    for (const KLDAP::LdapResult &result : results) {
+    for (const KLDAPWidgets::LdapResult &result : results) {
         KContacts::Addressee contact;
         contact.setNameFromString(result.name);
         contact.setEmails(result.email);
@@ -647,7 +647,7 @@ void AddresseeLineEditPrivate::slotEditCompletionOrder()
     }
 }
 
-KLDAP::LdapClientSearch *AddresseeLineEditPrivate::ldapSearch()
+KLDAPWidgets::LdapClientSearch *AddresseeLineEditPrivate::ldapSearch()
 {
     init(); // for AddresseeLineEditStatic::self()->ldapSearch
     return AddresseeLineEditManager::self()->ldapSearch();
@@ -716,8 +716,8 @@ void AddresseeLineEditPrivate::slotAkonadiSearchResult(KJob *job)
 void AddresseeLineEditPrivate::slotAkonadiCollectionsReceived(const Akonadi::Collection::List &collections)
 {
     KSharedConfig::Ptr config = KSharedConfig::openConfig(QStringLiteral("kpimcompletionorder"));
-    KConfigGroup groupCompletionWeights(config, "CompletionWeights");
-    KConfigGroup groupCompletionEnabled(config, "CompletionEnabled");
+    KConfigGroup groupCompletionWeights(config, QStringLiteral("CompletionWeights"));
+    KConfigGroup groupCompletionEnabled(config, QStringLiteral("CompletionEnabled"));
     for (const Akonadi::Collection &collection : collections) {
         if (collection.isValid()) {
             const QString sourceString = collection.displayName();
@@ -950,3 +950,5 @@ void AddresseeLineEditPrivate::mightBeGroupJobsAdd(Akonadi::ContactGroupSearchJo
 {
     mMightBeGroupJobs.append(job);
 }
+
+#include "moc_addresseelineedit_p.cpp"
