@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -10,12 +10,13 @@
 #include "addresseelineeditldap.h"
 #include "kmailcompletion.h"
 
+#include "pimcommonakonadi_debug.h"
 #include <KColorScheme>
 #include <KConfigGroup>
-#include <KLDAP/LdapClient>
+#include <KLDAPWidgets/LdapClient>
 #include <KSharedConfig>
 #include <QCoreApplication>
-#include <QNetworkConfigurationManager>
+#include <QNetworkInformation>
 #include <QTimer>
 
 using namespace PimCommon;
@@ -27,9 +28,8 @@ AddresseeLineEditManager::AddresseeLineEditManager()
     , mAddresseeLineEditAkonadi(new AddresseeLineEditAkonadi)
     , mAddressessLineEditLdap(new AddresseeLineEditLdap(this))
     , mAddressessLineEditBaloo(new AddresseeLineEditBaloo)
-    , mNetworkConfigMgr(new QNetworkConfigurationManager(QCoreApplication::instance()))
 {
-    KConfigGroup group(KSharedConfig::openConfig(), "AddressLineEdit");
+    KConfigGroup group(KSharedConfig::openConfig(), QStringLiteral("AddressLineEdit"));
     mShowOU = group.readEntry("ShowOU", false);
     mAutoGroupExpand = group.readEntry("AutoGroupExpand", false);
 }
@@ -113,10 +113,15 @@ void AddresseeLineEditManager::setAddressLineEdit(AddresseeLineEdit *addressLine
 
 bool AddresseeLineEditManager::isOnline() const
 {
-    return mNetworkConfigMgr->isOnline();
+    if (QNetworkInformation::loadBackendByFeatures(QNetworkInformation::Feature::Reachability)) {
+        return QNetworkInformation::instance()->reachability() == QNetworkInformation::Reachability::Online;
+    } else {
+        qCWarning(PIMCOMMONAKONADI_LOG) << "Couldn't find a working backend for QNetworkInformation";
+        return false;
+    }
 }
 
-KLDAP::LdapClientSearch *AddresseeLineEditManager::ldapSearch() const
+KLDAPWidgets::LdapClientSearch *AddresseeLineEditManager::ldapSearch() const
 {
     return mAddressessLineEditLdap->ldapSearch();
 }
@@ -208,7 +213,7 @@ bool AddresseeLineEditManager::showOU() const
 void AddresseeLineEditManager::setShowOU(bool checked)
 {
     if (checked != mShowOU) {
-        KConfigGroup group(KSharedConfig::openConfig(), "AddressLineEdit");
+        KConfigGroup group(KSharedConfig::openConfig(), QStringLiteral("AddressLineEdit"));
         group.writeEntry("ShowOU", checked);
         mShowOU = checked;
     }
@@ -223,7 +228,7 @@ void AddresseeLineEditManager::setAutoGroupExpand(bool checked)
 {
     if (mAutoGroupExpand != checked) {
         mAutoGroupExpand = checked;
-        KConfigGroup group(KSharedConfig::openConfig(), "AddressLineEdit");
+        KConfigGroup group(KSharedConfig::openConfig(), QStringLiteral("AddressLineEdit"));
         group.writeEntry("AutoGroupExpand", mAutoGroupExpand);
     }
 }
