@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -18,6 +18,6 @@ namespace PimCommon
 class PIMCOMMONAKONADI_EXPORT AddresseeLineEditUtil
 {
 public:
-    Q_REQUIRED_RESULT static QString adaptPasteMails(const QString &str);
+    [[nodiscard]] static QString adaptPasteMails(const QString &str);
 };
 }
