@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -20,72 +20,70 @@ BlackListBalooEmailCompletionWidgetTest::BlackListBalooEmailCompletionWidgetTest
 {
 }
 
-BlackListBalooEmailCompletionWidgetTest::~BlackListBalooEmailCompletionWidgetTest()
-{
-}
+BlackListBalooEmailCompletionWidgetTest::~BlackListBalooEmailCompletionWidgetTest() = default;
 
 void BlackListBalooEmailCompletionWidgetTest::shouldHaveDefaultValue()
 {
     PimCommon::BlackListBalooEmailCompletionWidget widget;
     widget.show();
     QVERIFY(QTest::qWaitForWindowExposed(&widget));
-    auto *searchLabel = widget.findChild<QLabel *>(QStringLiteral("search_label"));
+    auto searchLabel = widget.findChild<QLabel *>(QStringLiteral("search_label"));
     QVERIFY(searchLabel);
 
-    auto *searchLineEdit = widget.findChild<QLineEdit *>(QStringLiteral("search_lineedit"));
+    auto searchLineEdit = widget.findChild<QLineEdit *>(QStringLiteral("search_lineedit"));
     QVERIFY(searchLineEdit);
     QVERIFY(searchLineEdit->isClearButtonEnabled());
     QVERIFY(searchLineEdit->text().isEmpty());
 
-    auto *seachButton = widget.findChild<QPushButton *>(QStringLiteral("search_button"));
+    auto seachButton = widget.findChild<QPushButton *>(QStringLiteral("search_button"));
     QVERIFY(seachButton);
     QVERIFY(!seachButton->isEnabled());
 
-    auto *moreResult = widget.findChild<QLabel *>(QStringLiteral("moreresultlabel"));
+    auto moreResult = widget.findChild<QLabel *>(QStringLiteral("moreresultlabel"));
     QVERIFY(moreResult);
     QVERIFY(!moreResult->isVisible());
 
-    auto *mNumberOfEmailsFound = widget.findChild<QLabel *>(QStringLiteral("numberofemailsfound"));
+    auto mNumberOfEmailsFound = widget.findChild<QLabel *>(QStringLiteral("numberofemailsfound"));
     QVERIFY(mNumberOfEmailsFound);
     QVERIFY(mNumberOfEmailsFound->text().isEmpty());
 
-    auto *showAllBlackListedEmails = widget.findChild<QPushButton *>(QStringLiteral("show_blacklisted_email_button"));
+    auto showAllBlackListedEmails = widget.findChild<QPushButton *>(QStringLiteral("show_blacklisted_email_button"));
     QVERIFY(showAllBlackListedEmails);
 
-    auto *emailList = widget.findChild<PimCommon::BlackListBalooEmailList *>(QStringLiteral("email_list"));
+    auto emailList = widget.findChild<PimCommon::BlackListBalooEmailList *>(QStringLiteral("email_list"));
     QVERIFY(emailList);
 
-    auto *selectButton = widget.findChild<QPushButton *>(QStringLiteral("select_email"));
+    auto selectButton = widget.findChild<QPushButton *>(QStringLiteral("select_email"));
     QVERIFY(selectButton);
     QVERIFY(!selectButton->isEnabled());
-    auto *unselectButton = widget.findChild<QPushButton *>(QStringLiteral("unselect_email"));
+    auto unselectButton = widget.findChild<QPushButton *>(QStringLiteral("unselect_email"));
     QVERIFY(unselectButton);
     QVERIFY(!unselectButton->isEnabled());
 
-    auto *excludeDomainLabel = widget.findChild<QLabel *>(QStringLiteral("domain_label"));
+    auto excludeDomainLabel = widget.findChild<QLabel *>(QStringLiteral("domain_label"));
     QVERIFY(excludeDomainLabel);
 
-    auto *excludeDomainLineEdit = widget.findChild<QLineEdit *>(QStringLiteral("domain_lineedit"));
+    auto excludeDomainLineEdit = widget.findChild<QLineEdit *>(QStringLiteral("domain_lineedit"));
     QVERIFY(excludeDomainLineEdit);
     QVERIFY(excludeDomainLineEdit->text().isEmpty());
     QVERIFY(excludeDomainLineEdit->isClearButtonEnabled());
     QVERIFY(!excludeDomainLineEdit->placeholderText().isEmpty());
 
-    auto *searchInResult = widget.findChild<KListWidgetSearchLine *>(QStringLiteral("searchinresultlineedit"));
+    auto searchInResult = widget.findChild<KListWidgetSearchLine *>(QStringLiteral("searchinresultlineedit"));
     QVERIFY(searchInResult);
     QVERIFY(!searchInResult->placeholderText().isEmpty());
     QVERIFY(searchInResult->text().isEmpty());
     QVERIFY(searchInResult->isClearButtonEnabled());
 
-    auto *blackListWarning = widget.findChild<PimCommon::BlackListBalooEmailWarning *>(QStringLiteral("backlistwarning"));
+    auto blackListWarning = widget.findChild<PimCommon::BlackListBalooEmailWarning *>(QStringLiteral("backlistwarning"));
     QVERIFY(blackListWarning);
 }
 
 void BlackListBalooEmailCompletionWidgetTest::shouldEnablePushButtonWhenTestSizeSupperiorToTwo()
 {
     PimCommon::BlackListBalooEmailCompletionWidget widget;
-    auto *searchLineEdit = widget.findChild<QLineEdit *>(QStringLiteral("search_lineedit"));
-    auto *seachButton = widget.findChild<QPushButton *>(QStringLiteral("search_button"));
+    auto searchLineEdit = widget.findChild<QLineEdit *>(QStringLiteral("search_lineedit"));
+    auto seachButton = widget.findChild<QPushButton *>(QStringLiteral("search_button"));
     QVERIFY(!seachButton->isEnabled());
     searchLineEdit->setText(QStringLiteral("fo"));
     QVERIFY(!seachButton->isEnabled());
@@ -102,13 +100,13 @@ void BlackListBalooEmailCompletionWidgetTest::shouldChangeEnableSelectUnSelectBu
 {
     PimCommon::BlackListBalooEmailCompletionWidget widget;
 
-    auto *selectButton = widget.findChild<QPushButton *>(QStringLiteral("select_email"));
+    auto selectButton = widget.findChild<QPushButton *>(QStringLiteral("select_email"));
     QVERIFY(!selectButton->isEnabled());
 
-    auto *unselectButton = widget.findChild<QPushButton *>(QStringLiteral("unselect_email"));
+    auto unselectButton = widget.findChild<QPushButton *>(QStringLiteral("unselect_email"));
     QVERIFY(!unselectButton->isEnabled());
 
-    auto *emailList = widget.findChild<PimCommon::BlackListBalooEmailList *>(QStringLiteral("email_list"));
+    auto emailList = widget.findChild<PimCommon::BlackListBalooEmailList *>(QStringLiteral("email_list"));
     QVERIFY((emailList->setEmailFound(QStringList() << QStringLiteral("foo") << QStringLiteral("bla") << QStringLiteral("bli")) > 0));
 
     emailList->selectAll();
@@ -121,3 +119,5 @@ void BlackListBalooEmailCompletionWidgetTest::shouldChangeEnableSelectUnSelectBu
 }
 
 QTEST_MAIN(BlackListBalooEmailCompletionWidgetTest)
+
+#include "moc_blacklistbalooemailcompletionwidgettest.cpp"
