@@ -50,25 +50,25 @@ CompletionConfigureDialog::CompletionConfigureDialog(QWidget *parent)
     auto mainLayout = new QVBoxLayout(this);
 
     d->mTabWidget = new QTabWidget(this);
-    d->mTabWidget->setObjectName(QStringLiteral("tabwidget"));
+    d->mTabWidget->setObjectName(QLatin1StringView("tabwidget"));
     mainLayout->addWidget(d->mTabWidget);
 
     d->mCompletionOrderWidget = new PimCommon::CompletionOrderWidget(this);
-    d->mCompletionOrderWidget->setObjectName(QStringLiteral("completionorder_widget"));
+    d->mCompletionOrderWidget->setObjectName(QLatin1StringView("completionorder_widget"));
     d->mTabWidget->addTab(d->mCompletionOrderWidget, i18n("Completion Order"));
 
     d->mRecentaddressWidget = new PimCommon::RecentAddressWidget(this);
-    d->mRecentaddressWidget->setObjectName(QStringLiteral("recentaddress_widget"));
+    d->mRecentaddressWidget->setObjectName(QLatin1StringView("recentaddress_widget"));
     d->mTabWidget->addTab(d->mRecentaddressWidget, i18n("Recent Address"));
 
 #if !DISABLE_AKONADI_SEARCH
     d->mBlackListBalooWidget = new PimCommon::BlackListBalooEmailCompletionWidget(this);
-    d->mBlackListBalooWidget->setObjectName(QStringLiteral("blacklistbaloo_widget"));
+    d->mBlackListBalooWidget->setObjectName(QLatin1StringView("blacklistbaloo_widget"));
     d->mTabWidget->addTab(d->mBlackListBalooWidget, i18n("Blacklist Email Address"));
 #endif
 
     auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Apply | QDialogButtonBox::Cancel, this);
-    buttonBox->setObjectName(QStringLiteral("buttonbox"));
+    buttonBox->setObjectName(QLatin1StringView("buttonbox"));
     connect(buttonBox, &QDialogButtonBox::accepted, this, &CompletionConfigureDialog::slotSaveAndClose);
     connect(buttonBox->button(QDialogButtonBox::Apply), &QPushButton::clicked, this, &CompletionConfigureDialog::slotSave);
     connect(buttonBox, &QDialogButtonBox::rejected, this, &QDialog::reject);
