@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -17,9 +17,7 @@ using namespace PimCommon;
 class AddressessLineEditPluginInfo
 {
 public:
-    AddressessLineEditPluginInfo()
-    {
-    }
+    AddressessLineEditPluginInfo() = default;
 
     KPluginMetaData data;
     QString metaDataFileNameBaseName;
@@ -38,15 +36,15 @@ QString pluginVersion()
 class PimCommon::AddressessLineEditPluginManagerPrivate
 {
 public:
-    AddressessLineEditPluginManagerPrivate(AddressessLineEditPluginManager *qq)
+    explicit AddressessLineEditPluginManagerPrivate(AddressessLineEditPluginManager *qq)
         : q(qq)
     {
         initializePlugins();
     }
 
     void loadPlugin(AddressessLineEditPluginInfo *item);
-    QVector<PimCommon::AddressessLineEditAbstractPlugin *> pluginsList() const;
-    QVector<AddressessLineEditPluginInfo> mPluginList;
+    [[nodiscard]] QList<PimCommon::AddressessLineEditAbstractPlugin *> pluginsList() const;
+    QList<AddressessLineEditPluginInfo> mPluginList;
     bool initializePlugins();
 
 private:
@@ -58,9 +56,8 @@ bool AddressessLineEditPluginManagerPrivate::initializePlugins()
     if (!mPluginList.isEmpty()) {
         return true;
     }
-    const QVector<KPluginMetaData> plugins = KPluginMetaData::findPlugins(QStringLiteral("addressline"));
-
-    QVectorIterator<KPluginMetaData> i(plugins);
+    const QList<KPluginMetaData> plugins = KPluginMetaData::findPlugins(QStringLiteral("addressline"));
+    QListIterator<KPluginMetaData> i(plugins);
     i.toBack();
     while (i.hasPrevious()) {
         AddressessLineEditPluginInfo info;
@@ -76,8 +73,8 @@ bool AddressessLineEditPluginManagerPrivate::initializePlugins()
             qCWarning(PIMCOMMONAKONADI_LOG) << "Plugin " << data.name() << " doesn't have correction plugin version. It will not be loaded.";
         }
     }
-    const QVector<AddressessLineEditPluginInfo>::iterator end(mPluginList.end());
-    for (QVector<AddressessLineEditPluginInfo>::iterator it = mPluginList.begin(); it != end; ++it) {
+    const QList<AddressessLineEditPluginInfo>::iterator end(mPluginList.end());
+    for (QList<AddressessLineEditPluginInfo>::iterator it = mPluginList.begin(); it != end; ++it) {
         loadPlugin(&(*it));
     }
     return true;
@@ -92,11 +89,11 @@ void AddressessLineEditPluginManagerPrivate::loadPlugin(AddressessLineEditPlugin
     }
 }
 
-QVector<PimCommon::AddressessLineEditAbstractPlugin *> AddressessLineEditPluginManagerPrivate::pluginsList() const
+QList<PimCommon::AddressessLineEditAbstractPlugin *> AddressessLineEditPluginManagerPrivate::pluginsList() const
 {
-    QVector<PimCommon::AddressessLineEditAbstractPlugin *> lst;
-    const QVector<AddressessLineEditPluginInfo>::ConstIterator end(mPluginList.constEnd());
-    for (QVector<AddressessLineEditPluginInfo>::ConstIterator it = mPluginList.constBegin(); it != end; ++it) {
+    QList<PimCommon::AddressessLineEditAbstractPlugin *> lst;
+    const QList<AddressessLineEditPluginInfo>::ConstIterator end(mPluginList.constEnd());
+    for (QList<AddressessLineEditPluginInfo>::ConstIterator it = mPluginList.constBegin(); it != end; ++it) {
         if (auto plugin = (*it).plugin) {
             lst << plugin;
         }
@@ -118,16 +115,16 @@ AddressessLineEditPluginManager *AddressessLineEditPluginManager::self()
     return &s_self;
 }
 
-QVector<PimCommon::AddressessLineEditAbstractPlugin *> AddressessLineEditPluginManager::pluginsList() const
+QList<PimCommon::AddressessLineEditAbstractPlugin *> AddressessLineEditPluginManager::pluginsList() const
 {
     return d->pluginsList();
 }
 
 PimCommon::AddressessLineEditAbstractPlugin *AddressessLineEditPluginManager::plugin(const QString &identifier)
 {
-    const QVector<PimCommon::AddressessLineEditAbstractPlugin *> lstPlugins = pluginsList();
+    const QList<PimCommon::AddressessLineEditAbstractPlugin *> lstPlugins = pluginsList();
     for (PimCommon::AddressessLineEditAbstractPlugin *p : lstPlugins) {
-        const QVector<AddressessLineEditAbstractPluginInfo> lstPluginsInfo = p->names();
+        const QList<AddressessLineEditAbstractPluginInfo> lstPluginsInfo = p->names();
         for (const AddressessLineEditAbstractPluginInfo &info : lstPluginsInfo) {
             if (info.identifier == identifier) {
                 return p;
@@ -136,3 +133,5 @@ PimCommon::AddressessLineEditAbstractPlugin *AddressessLineEditPluginManager::pl
     }
     return {};
 }
+
+#include "moc_addressesslineeditpluginmanager.cpp"
