@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -28,10 +28,9 @@ public:
     static AddressessLineEditPluginManager *self();
 
     PimCommon::AddressessLineEditAbstractPlugin *plugin(const QString &identifier);
-    QVector<PimCommon::AddressessLineEditAbstractPlugin *> pluginsList() const;
+    QList<PimCommon::AddressessLineEditAbstractPlugin *> pluginsList() const;
 
 private:
     std::unique_ptr<AddressessLineEditPluginManagerPrivate> const d;
 };
 }
-
