@@ -30,16 +30,17 @@ public:
 
     void setAddresses(const QStringList &addrs);
     void storeAddresses(KConfig *config);
-    Q_REQUIRED_RESULT bool wasChanged() const;
+    [[nodiscard]] bool wasChanged() const;
 
 protected:
     void updateButtonState();
     bool eventFilter(QObject *o, QEvent *e) override;
 
 private:
-    void slotAddItem();
-    void slotRemoveItem();
-    void slotUpdateAddButton(const QString &str);
+    PIMCOMMONAKONADI_NO_EXPORT void slotAddItem();
+    PIMCOMMONAKONADI_NO_EXPORT void slotRemoveItem();
+    PIMCOMMONAKONADI_NO_EXPORT void slotUpdateAddButton(const QString &str);
+    PIMCOMMONAKONADI_NO_EXPORT void slotCustomContextMenuRequested(const QPoint &pos);
     QLineEdit *const mLineEdit;
     QToolButton *const mNewButton;
     QToolButton *const mRemoveButton;
