@@ -71,9 +71,9 @@ void SelectMultiCollectionWidget::slotCollectionsTreeFetched()
     mCheckedCollectionWidget->folderTreeView()->expandAll();
 }
 
-QVector<Akonadi::Collection> SelectMultiCollectionWidget::selectedCollection(const QModelIndex &parent) const
+QList<Akonadi::Collection> SelectMultiCollectionWidget::selectedCollection(const QModelIndex &parent) const
 {
-    QVector<Akonadi::Collection> lst;
+    QList<Akonadi::Collection> lst;
 
     const int nbCol = mCheckedCollectionWidget->checkableProxy()->rowCount(parent);
     for (int i = 0; i < nbCol; ++i) {
@@ -88,3 +88,5 @@ QVector<Akonadi::Collection> SelectMultiCollectionWidget::selectedCollection(con
     }
     return lst;
 }
+
+#include "moc_selectmulticollectionwidget.cpp"
