@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -26,7 +26,7 @@ public:
     QString mPluginDirectory;
     QWidget *mParentWidget = nullptr;
     KActionCollection *mActionCollection = nullptr;
-    QVector<PimCommon::GenericPluginInterface *> mListGenericInterface;
+    QList<PimCommon::GenericPluginInterface *> mListGenericInterface;
     GenericPluginManager *mGenericPluginManager = nullptr;
 };
 
@@ -210,7 +210,7 @@ QHash<PimCommon::ActionType::Type, QList<QAction *>> PluginInterface::actionsTyp
     return listType;
 }
 
-QVector<PimCommon::PluginUtilData> PluginInterface::pluginsDataList() const
+QList<PimCommon::PluginUtilData> PluginInterface::pluginsDataList() const
 {
     return d->mGenericPluginManager->pluginsDataList();
 }
@@ -229,3 +229,5 @@ PimCommon::GenericPlugin *PluginInterface::pluginFromIdentifier(const QString &i
 {
     return d->mGenericPluginManager->pluginFromIdentifier(id);
 }
+
+#include "moc_plugininterface.cpp"
