@@ -28,7 +28,7 @@ public:
     ~PluginInterface() override;
 
     void setParentWidget(QWidget *widget);
-    Q_REQUIRED_RESULT QHash<PimCommon::ActionType::Type, QList<QAction *>> actionsType();
+    [[nodiscard]] QHash<PimCommon::ActionType::Type, QList<QAction *>> actionsType();
     void createPluginInterface();
 
     void setPluginName(const QString &name);
@@ -42,14 +42,14 @@ public:
 
     void setActionCollection(KActionCollection *ac);
 
-    Q_REQUIRED_RESULT QVector<PimCommon::PluginUtilData> pluginsDataList() const;
-    Q_REQUIRED_RESULT QString configGroupName() const;
-    Q_REQUIRED_RESULT QString configPrefixSettingKey() const;
+    [[nodiscard]] QList<PimCommon::PluginUtilData> pluginsDataList() const;
+    [[nodiscard]] QString configGroupName() const;
+    [[nodiscard]] QString configPrefixSettingKey() const;
 
     PimCommon::GenericPlugin *pluginFromIdentifier(const QString &id);
     void clearPluginActions(const QString &prefix, KXMLGUIClient *guiClient);
 private Q_SLOTS:
-    void slotPluginActivated(PimCommon::AbstractGenericPluginInterface *interface);
+    PIMCOMMONAKONADI_NO_EXPORT void slotPluginActivated(PimCommon::AbstractGenericPluginInterface *interface);
 
 private:
     std::unique_ptr<PluginInterfacePrivate> const d;
