@@ -9,11 +9,11 @@
 
 #include "ldapsearchdialog.h"
 
-#include <KLDAP/LdapClient>
+#include <KLDAPWidgets/LdapClient>
 
-#include <KLDAP/LdapClientSearchConfig>
-#include <KLDAP/LdapSearchClientReadConfigServerJob>
-#include <Libkdepim/LineEditCatchReturnKey>
+#include <KLDAPWidgets/LdapClientSearchConfig>
+#include <KLDAPWidgets/LdapSearchClientReadConfigServerJob>
+#include <KLineEditEventHandler>
 #include <Libkdepim/ProgressIndicatorLabel>
 
 #include <QApplication>
@@ -41,8 +41,8 @@
 #include <QComboBox>
 #include <QDialogButtonBox>
 #include <QLineEdit>
-#include <kldap/ldapobject.h>
-#include <kldap/ldapserver.h>
+#include <kldapcore/ldapobject.h>
+#include <kldapcore/ldapserver.h>
 
 #include <KConfigGroup>
 #include <KGuiItem>
@@ -67,12 +67,12 @@ static QString asUtf8(const QByteArray &val)
     }
 }
 
-static QString join(const KLDAP::LdapAttrValue &lst, const QString &sep)
+static QString join(const KLDAPCore::LdapAttrValue &lst, const QString &sep)
 {
     QString res;
     bool already = false;
-    KLDAP::LdapAttrValue::ConstIterator end(lst.constEnd());
-    for (KLDAP::LdapAttrValue::ConstIterator it = lst.constBegin(); it != end; ++it) {
+    KLDAPCore::LdapAttrValue::ConstIterator end(lst.constEnd());
+    for (KLDAPCore::LdapAttrValue::ConstIterator it = lst.constBegin(); it != end; ++it) {
         if (already) {
             res += sep;
         }
@@ -148,7 +148,7 @@ static QString makeFilter(const QString &query, LdapSearchDialog::FilterType att
     return result;
 }
 
-static KContacts::Addressee convertLdapAttributesToAddressee(const KLDAP::LdapAttrMap &attrs)
+static KContacts::Addressee convertLdapAttributesToAddressee(const KLDAPCore::LdapAttrMap &attrs)
 {
     KContacts::Addressee addr;
 
@@ -158,8 +158,8 @@ static KContacts::Addressee convertLdapAttributesToAddressee(const KLDAP::LdapAt
     }
 
     // email
-    KLDAP::LdapAttrValue lst = attrs[QStringLiteral("mail")];
-    KLDAP::LdapAttrValue::ConstIterator it = lst.constBegin();
+    KLDAPCore::LdapAttrValue lst = attrs[QStringLiteral("mail")];
+    KLDAPCore::LdapAttrValue::ConstIterator it = lst.constBegin();
     bool pref = true;
     while (it != lst.constEnd()) {
         KContacts::Email email(asUtf8(*it));
@@ -231,7 +231,7 @@ public:
     {
     }
 
-    void addContact(const KLDAP::LdapAttrMap &contact, const QString &server)
+    void addContact(const KLDAPCore::LdapAttrMap &contact, const QString &server)
     {
         beginResetModel();
         mContactList.append(contact);
@@ -239,16 +239,16 @@ public:
         endResetModel();
     }
 
-    Q_REQUIRED_RESULT QPair<KLDAP::LdapAttrMap, QString> contact(const QModelIndex &index) const
+    [[nodiscard]] QPair<KLDAPCore::LdapAttrMap, QString> contact(const QModelIndex &index) const
     {
         if (!index.isValid() || index.row() < 0 || index.row() >= mContactList.count()) {
-            return qMakePair(KLDAP::LdapAttrMap(), QString());
+            return qMakePair(KLDAPCore::LdapAttrMap(), QString());
         }
 
         return qMakePair(mContactList.at(index.row()), mServerList.at(index.row()));
     }
 
-    Q_REQUIRED_RESULT QString email(const QModelIndex &index) const
+    [[nodiscard]] QString email(const QModelIndex &index) const
     {
         if (!index.isValid() || index.row() < 0 || index.row() >= mContactList.count()) {
             return {};
@@ -257,7 +257,7 @@ public:
         return asUtf8(mContactList.at(index.row()).value(QStringLiteral("mail")).first()).trimmed();
     }
 
-    Q_REQUIRED_RESULT QString fullName(const QModelIndex &index) const
+    [[nodiscard]] QString fullName(const QModelIndex &index) const
     {
         if (!index.isValid() || index.row() < 0 || index.row() >= mContactList.count()) {
             return {};
@@ -274,7 +274,7 @@ public:
         endResetModel();
     }
 
-    Q_REQUIRED_RESULT int rowCount(const QModelIndex &parent = QModelIndex()) const override
+    [[nodiscard]] int rowCount(const QModelIndex &parent = QModelIndex()) const override
     {
         if (!parent.isValid()) {
             return mContactList.count();
@@ -283,7 +283,7 @@ public:
         }
     }
 
-    Q_REQUIRED_RESULT int columnCount(const QModelIndex &parent = QModelIndex()) const override
+    [[nodiscard]] int columnCount(const QModelIndex &parent = QModelIndex()) const override
     {
         if (!parent.isValid()) {
             return 18;
@@ -292,7 +292,7 @@ public:
         }
     }
 
-    Q_REQUIRED_RESULT QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const override
+    [[nodiscard]] QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const override
     {
         if (orientation == Qt::Vertical || role != Qt::DisplayRole || section < 0 || section > 17) {
             return {};
@@ -340,7 +340,7 @@ public:
         }
     }
 
-    Q_REQUIRED_RESULT QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override
+    [[nodiscard]] QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override
     {
         if (!index.isValid()) {
             return {};
@@ -358,7 +358,7 @@ public:
             return {};
         }
 
-        const KLDAP::LdapAttrMap map = mContactList.at(index.row());
+        const KLDAPCore::LdapAttrMap map = mContactList.at(index.row());
 
         switch (index.column()) {
         case 0:
@@ -403,7 +403,7 @@ public:
     }
 
 private:
-    QVector<KLDAP::LdapAttrMap> mContactList;
+    QList<KLDAPCore::LdapAttrMap> mContactList;
     QStringList mServerList;
 };
 
@@ -415,9 +415,9 @@ public:
     {
     }
 
-    QVector<QPair<KLDAP::LdapAttrMap, QString>> selectedItems()
+    QList<QPair<KLDAPCore::LdapAttrMap, QString>> selectedItems()
     {
-        QVector<QPair<KLDAP::LdapAttrMap, QString>> contacts;
+        QList<QPair<KLDAPCore::LdapAttrMap, QString>> contacts;
 
         const QModelIndexList selected = mResultView->selectionModel()->selectedRows();
         const int numberOfSelectedElement(selected.count());
@@ -433,7 +433,7 @@ public:
     void restoreSettings();
     void cancelQuery();
 
-    void slotAddResult(const KLDAP::LdapClient &, const KLDAP::LdapObject &);
+    void slotAddResult(const KLDAPWidgets::LdapClient &, const KLDAPCore::LdapObject &);
     void slotSetScope(bool);
     void slotStartSearch();
     void slotStopSearch();
@@ -447,7 +447,7 @@ public:
     KGuiItem startSearchGuiItem;
     KGuiItem stopSearchGuiItem;
     int mNumHosts = 0;
-    QList<KLDAP::LdapClient *> mLdapClientList;
+    QList<KLDAPWidgets::LdapClient *> mLdapClientList;
     bool mIsConfigured = false;
     KContacts::Addressee::List mSelectedContacts;
 
@@ -544,7 +544,7 @@ LdapSearchDialog::LdapSearchDialog(QWidget *parent)
     auto quickSearchLineLayout = new QHBoxLayout;
     quickSearchLineLayout->addStretch();
     d->searchLine = new QLineEdit;
-    new KPIM::LineEditCatchReturnKey(d->searchLine, this);
+    KLineEditEventHandler::catchReturnKey(d->searchLine);
     d->searchLine->setClearButtonEnabled(true);
     d->searchLine->setPlaceholderText(i18n("Search in result"));
     quickSearchLineLayout->addWidget(d->searchLine);
@@ -650,23 +650,23 @@ void LdapSearchDialog::LdapSearchDialogPrivate::restoreSettings()
     qDeleteAll(mLdapClientList);
     mLdapClientList.clear();
 
-    KConfig *config = KLDAP::LdapClientSearchConfig::config();
+    KConfig *config = KLDAPWidgets::LdapClientSearchConfig::config();
 
-    KConfigGroup searchGroup(config, "LDAPSearch");
+    KConfigGroup searchGroup(config, QStringLiteral("LDAPSearch"));
     mSearchType->setCurrentIndex(searchGroup.readEntry("SearchType", 0));
 
     // then read the config file and register all selected
     // server in the list
-    KConfigGroup group(config, "LDAP");
+    KConfigGroup group(config, QStringLiteral("LDAP"));
     mNumHosts = group.readEntry("NumSelectedHosts", 0);
     if (!mNumHosts) {
         mIsConfigured = false;
     } else {
         mIsConfigured = true;
-        auto clientSearchConfig = new KLDAP::LdapClientSearchConfig;
+        auto clientSearchConfig = new KLDAPWidgets::LdapClientSearchConfig;
         for (int j = 0; j < mNumHosts; ++j) {
-            auto ldapClient = new KLDAP::LdapClient(0, q);
-            auto job = new KLDAP::LdapSearchClientReadConfigServerJob(q);
+            auto ldapClient = new KLDAPWidgets::LdapClient(0, q);
+            auto job = new KLDAPWidgets::LdapSearchClientReadConfigServerJob(q);
             job->setCurrentIndex(j);
             job->setActive(true);
             job->setConfig(group);
@@ -682,10 +682,10 @@ void LdapSearchDialog::LdapSearchDialogPrivate::restoreSettings()
             ldapClient->setAttributes(attrs);
 
             // clang-format off
-            q->connect(ldapClient, SIGNAL(result(KLDAP::LdapClient,KLDAP::LdapObject)), q, SLOT(slotAddResult(KLDAP::LdapClient,KLDAP::LdapObject)));
+            q->connect(ldapClient, SIGNAL(result(KLDAPWidgets::LdapClient,KLDAPCore::LdapObject)), q, SLOT(slotAddResult(KLDAPWidgets::LdapClient,KLDAPCore::LdapObject)));
             // clang-format on
             q->connect(ldapClient, SIGNAL(done()), q, SLOT(slotSearchDone()));
-            q->connect(ldapClient, &KLDAP::LdapClient::error, q, [this](const QString &err) {
+            q->connect(ldapClient, &KLDAPWidgets::LdapClient::error, q, [this](const QString &err) {
                 slotError(err);
             });
 
@@ -695,10 +695,10 @@ void LdapSearchDialog::LdapSearchDialogPrivate::restoreSettings()
 
         mModel->clear();
     }
-    KConfigGroup groupHeader(config, "Headers");
+    KConfigGroup groupHeader(config, QStringLiteral("Headers"));
     mResultView->horizontalHeader()->restoreState(groupHeader.readEntry("HeaderState", QByteArray()));
 
-    KConfigGroup groupSize(config, "Size");
+    KConfigGroup groupSize(config, QStringLiteral("Size"));
     const QSize dialogSize = groupSize.readEntry("Size", QSize());
     if (dialogSize.isValid()) {
         q->resize(dialogSize);
@@ -709,15 +709,15 @@ void LdapSearchDialog::LdapSearchDialogPrivate::restoreSettings()
 
 void LdapSearchDialog::LdapSearchDialogPrivate::saveSettings()
 {
-    KConfig *config = KLDAP::LdapClientSearchConfig::config();
-    KConfigGroup group(config, "LDAPSearch");
+    KConfig *config = KLDAPWidgets::LdapClientSearchConfig::config();
+    KConfigGroup group(config, QStringLiteral("LDAPSearch"));
     group.writeEntry("SearchType", mSearchType->currentIndex());
 
-    KConfigGroup groupHeader(config, "Headers");
+    KConfigGroup groupHeader(config, QStringLiteral("Headers"));
     groupHeader.writeEntry("HeaderState", mResultView->horizontalHeader()->saveState());
     groupHeader.sync();
 
-    KConfigGroup size(config, "Size");
+    KConfigGroup size(config, QStringLiteral("Size"));
     size.writeEntry("Size", q->size());
     size.sync();
 
@@ -726,19 +726,19 @@ void LdapSearchDialog::LdapSearchDialogPrivate::saveSettings()
 
 void LdapSearchDialog::LdapSearchDialogPrivate::cancelQuery()
 {
-    for (KLDAP::LdapClient *client : std::as_const(mLdapClientList)) {
+    for (KLDAPWidgets::LdapClient *client : std::as_const(mLdapClientList)) {
         client->cancelQuery();
     }
 }
 
-void LdapSearchDialog::LdapSearchDialogPrivate::slotAddResult(const KLDAP::LdapClient &client, const KLDAP::LdapObject &obj)
+void LdapSearchDialog::LdapSearchDialogPrivate::slotAddResult(const KLDAPWidgets::LdapClient &client, const KLDAPCore::LdapObject &obj)
 {
     mModel->addContact(obj.attributes(), client.server().host());
 }
 
 void LdapSearchDialog::LdapSearchDialogPrivate::slotSetScope(bool rec)
 {
-    for (KLDAP::LdapClient *client : std::as_const(mLdapClientList)) {
+    for (KLDAPWidgets::LdapClient *client : std::as_const(mLdapClientList)) {
         if (rec) {
             client->setScope(QStringLiteral("sub"));
         } else {
@@ -772,7 +772,7 @@ void LdapSearchDialog::LdapSearchDialogPrivate::slotStartSearch()
 
     // loop in the list and run the KLDAP::LdapClients
     mModel->clear();
-    for (KLDAP::LdapClient *client : std::as_const(mLdapClientList)) {
+    for (KLDAPWidgets::LdapClient *client : std::as_const(mLdapClientList)) {
         client->startQuery(filter);
     }
 
@@ -788,7 +788,7 @@ void LdapSearchDialog::LdapSearchDialogPrivate::slotStopSearch()
 void LdapSearchDialog::LdapSearchDialogPrivate::slotSearchDone()
 {
     // If there are no more active clients, we are done.
-    for (KLDAP::LdapClient *client : std::as_const(mLdapClientList)) {
+    for (KLDAPWidgets::LdapClient *client : std::as_const(mLdapClientList)) {
         if (client->isActive()) {
             return;
         }
@@ -836,7 +836,7 @@ void LdapSearchDialog::slotUser1()
 
     d->mSelectedContacts.clear();
 
-    const QVector<QPair<KLDAP::LdapAttrMap, QString>> &items = d->selectedItems();
+    const QList<QPair<KLDAPCore::LdapAttrMap, QString>> &items = d->selectedItems();
 
     if (!items.isEmpty()) {
         const QDateTime now = QDateTime::currentDateTime();
@@ -866,7 +866,7 @@ void LdapSearchDialog::slotUser2()
 
     QPointer<KCMultiDialog> dialog = new KCMultiDialog(this);
     dialog->setWindowTitle(i18nc("@title:window", "Configure the Address Book LDAP Settings"));
-    dialog->addModule(KPluginMetaData(QStringLiteral("pim/kcms/kaddressbook/kcm_ldap")));
+    dialog->addModule(KPluginMetaData(QStringLiteral("pim6/kcms/kaddressbook/kcm_ldap")));
 
     if (dialog->exec()) { // krazy:exclude=crashy
         d->restoreSettings();
